<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Oznámení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>1 sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation>Počet citovaných znaků</translation>
    </message>
    <message>
        <source>System notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom expiration timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expiration timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show message content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
